@@ -1,7 +1,9 @@
 matrix.graph <-
 function(rl,mat)
   {
-    if(class(rl) != "landscape") 
+    
+  if(!inherits(rl, "landscape"))
+  #if(class(rl) != "landscape") 
         {
           stop(paste(rl, " should be an object of class class 'landscape'.", sep=""), call. = FALSE)
         }
